@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.024';
+our $VERSION = '0.025';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -439,9 +439,13 @@ sub ACTION_test {
   my $self = shift;
   $self->SUPER::ACTION_test;
 
-  local $CWD = $self->config_data( 'working_directory' );
   print "Testing library (if applicable) ... ";
-  $self->alien_do_commands('test') or die "Failed\n";
+  if ($self->config_data( 'install_type' ) eq 'share') {
+    if (defined (my $wdir = $self->config_data( 'working_directory' ))) {
+      local $CWD = $wdir;
+      $self->alien_do_commands('test') or die "Failed\n";
+    }
+  }
   print "Done\n";
 }
 
@@ -547,7 +551,7 @@ sub alien_check_installed_version {
   my $command = $self->alien_version_check;
 
   my %result = $self->do_system($command, {verbose => 0});
-  my $version = $result{stdout} || 0;
+  my $version = ($result{success} && $result{stdout}) || 0;
 
   return $version;
 }
@@ -825,11 +829,14 @@ sub do_system {
 
   print "+ @args\n";
 
+  my $old_super_verbose = $self->verbose;
+  $self->verbose(0);
   my ($out, $err, $success) = 
     $verbose
     ? tee     { $self->SUPER::do_system(@args) }
     : capture { $self->SUPER::do_system(@args) }
   ;
+  $self->verbose($old_super_verbose);
 
   my %return = (
     stdout => $out,
